@@ -10,6 +10,7 @@ use Method::Cached
         storage_args  => [
             { servers    => [qw/ 127.0.0.1:11211 /] },
         ],
+        key_rule      => 'SERIALIZE', # SERIALIZE / LIST
     },
     -domains => {
         'memcached-fast' => {
@@ -17,17 +18,18 @@ use Method::Cached
             storage_args  => [
                 { servers    => [qw/ 127.0.0.1:11211 /] },
             ],
-            key_rule      => 'LIST', # SERIALIZE / LIST
+            key_rule      => 'SERIALIZE', # SERIALIZE / LIST
         },
         'fastmmap'       => {
             storage_class => 'Cache::FastMmap',
             storage_args  => [
                 share_file     => '/tmp/fastmmap.bin',
-                unlink_on_exit => 1,
+                unlink_on_exit => 0,
             ],
-            key_rule      => 'LIST', # SERIALIZE / LIST
+            key_rule      => 'SERIALIZE', # SERIALIZE / LIST
         },
-    }, ;
+    },
+;
 
 {
     package Dummy;
@@ -40,30 +42,28 @@ use Method::Cached
         fib($n - 1) + fib($n - 2);
     }
 
-    sub fib_default :Cached {
+    sub fib_default :Cached(5) {
         my $n = shift;
         return $n if $n < 2;
         fib_default($n - 1) + fib_default($n - 2);
     }
 
-    sub fib_memcached :Cached('memcached-fast') {
+    sub fib_memcached :Cached('memcached-fast', 5) {
         my $n = shift;
         return $n if $n < 2;
         fib_memcached($n - 1) + fib_memcached($n - 2);
     }
 
-    sub fib_fastmmap :Cached('cache-fastmmap') {
+    sub fib_fastmmap :Cached('cache-fastmmap', 5) {
         my $n = shift;
         return $n if $n < 2;
         fib_fastmmap($n - 1) + fib_fastmmap($n - 2);
     }
+
 }
 
 package main;
 
-# use Dummy;
-Dummy->import;
-
 use Benchmark qw/cmpthese timethese/;
 
 my $num = 13;
@@ -75,7 +75,7 @@ sub def_fib { $def_fib = $num; $def_fib = Dummy::fib_default($def_fib)  }
 sub mc_fib  { $mc_fib  = $num; $mc_fib  = Dummy::fib_memcached($mc_fib) }
 sub fm_fib  { $fm_fib  = $num; $fm_fib  = Dummy::fib_fastmmap($fm_fib)  }
 
-cmpthese(50000, {
+cmpthese(10000, {
     'fib'               => \&fib,
     'C(default)'        => \&def_fib,
     'C(Memcached-Fast)' => \&mc_fib,
